/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.commons.io.serialization;

import java.io.Serializable;

/**
 * Test fixture for {@link ValidatingObjectInputStreamTest}.
 */
public class MockSerializedClass implements Serializable {

    private static final long serialVersionUID = 2139985988735372175L;

    private final String str;

    MockSerializedClass(final String str) {
        this.str = str;
    }

    @Override
    public boolean equals(final Object obj) {
        if (!(obj instanceof MockSerializedClass)) {
            return false;
        }
        return str.equals(((MockSerializedClass) obj).str);
    }

    @Override
    public int hashCode() {
        return str.hashCode();
    }
}